<?php

namespace drp\AdminPanel\Sidebar;

class SidebarSingleItem extends SidebarItemBase implements SidebarItemInterface
{
    /**
     * Link to go to when the item is click.
     *
     * @var string
     */
    protected $link;

    /**
     * Whether to open the link in a new tab or not.
     *
     * @var boolean
     */
    protected $openInNewTab = false;

    /**
     * Constructor
     *
     * @param string  $icon         Icon to be displayed to the left of the text.
     * @param string  $text         Text to be displayed.
     * @param string  $link         Location the sidebar will take you to.
     * @param boolean $openInNewTab When the link is click if it should open in a new tab.
     */
    public function __construct(
        $icon,
        $text,
        $link,
        $showCallable = null,
        $openInNewTab = false
    ) {
        $this->link = strip_tags($link);
        $this->openInNewTab($openInNewTab);

        parent::__construct($icon, $text, $showCallable);
    }

    /**
     * Builds the HTML version of this sidebar item.
     *
     * @param  string $currentPath Current path the admin panel is on.
     * @return string
     */
    public function render($currentPath)
    {
        if ($this->shouldRender() === false) {
            return '';
        }

        $html =
        '<li class="' . $this->getActive($currentPath) . '">' .
            '<a href="' . $this->getLink() . '" ' . $this->getOpenInNewTab() . '>' .
                '<span>' . $this->getIconHtml() . ' ' . $this->text . '</span>' .
            '</a>' .
        '</li>';

        return $html;
    }

    /**
     * Gets active class if the current path matches this item's link.
     *
     * @param  string $currentPath
     * @return string
     */
    protected function getActive($currentPath)
    {
        if ($currentPath == trim($this->link, '/')) {
            return 'active';
        }

        return '';
    }

    /**
     * Gets the target property if needed.
     *
     * @return string
     */
    protected function getOpenInNewTab()
    {
        if ($this->openInNewTab) {
            return 'target="_blank"';
        }

        return '';
    }

    /**
     * Gets the link associated with this item.
     *
     * @return string
     */
    public function getLink()
    {
        return $this->link;
    }

    /**
     * When this item is click it will open it in a new tab.
     *
     * @return self
     */
    public function openInNewTab($openInNewTab = true)
    {
        $this->openInNewTab = $openInNewTab;

        return $this;
    }
}
